<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Een eenvoudige, gebruiksvriendelijke Jabber/XMPP-client</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Licentie:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="obsolete">Broncode op GitHub</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Broncode online bekijken</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Een simpele, gebruiksvriendelijke Jabber/XMPP client</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Licentie:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Broncode op GitHub</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Ga Terug</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Wachtwoord veranderen</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Huidig wachtwoord:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nieuw wachtwoord:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Nieuw wachtwoord (opnieuw):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>De ingevulde wachtwoorden komen niet overeen.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Het huidige wachtwoord is ongeldig.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Uw moet verbonden zijn om uw wachtwoord te kunnen veranderen.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Nadat u uw wachtwoord heeft veranderd, zult u het opnieuw in moeten voeren op andere apparaten waarop u bent ingelogd.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Veranderen</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="unfinished">Fout bij het wijzigen van wachtwoord: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Bericht Kopiëren</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Bericht Bewerken</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Kopiëer downloadlink</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished">Kopiëer downloadlink</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Bericht opstellen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Versturen</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Afbeelding</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Geluid</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Document</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Ander bestand</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Selecteer een bestand</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Bericht met spoileralert versturen</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Spoilerhint</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Meldingen inschakelen</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Meldingen uitschakelen</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Profiel bekijken</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">Zoeken</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Sluiten</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Zoek naar beneden</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Alle bestanden</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished">Spoilerhint</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation type="unfinished">Bericht opstellen</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Zeer laag</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Zeer hoog</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Constante kwaliteit</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Constante bitsnelheid</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Gemiddelde bitsnelheid</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Twee passen</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished">Veranderen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Handelingen</translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Kon bestand niet opslaan: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Downloaden mislukt: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Favorieten</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Mensen</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Natuur</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Eten</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Activiteiten</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Reizigen</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Voorwerpen</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Symbolen</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Vlaggen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Zoeken</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Emoji&apos;s zoeken</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Selecteer een chat om een gesprek te beginnen</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Selecteer een bestand</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Ga naar bovenliggende map</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Sluiten</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Ga Vooruit</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Back</source>
        <translation type="vanished">Terug</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation type="vanished">Log uit</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Nodig vrienden uit</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Uitnodigingslink gekopieerd naar klembord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">Offline</translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>De link wordt geopend nadat u verbinding hebt gemaakt.</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">Er is geen wachtwoord gevonden. Voor alstublieft een wachtwoord in.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Geen geldige login-QR-code gevonden.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Log in</translation>
    </message>
    <message>
        <source>Log in to your XMPP Account</source>
        <translation type="vanished">Log in op uw XMPP-account</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Uw Jabber-ID:</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Uw diaspora*-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">gebruiker@voorbeeld.nl</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">gebruiker@diaspora.pod</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Uw Wachtwoord:</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Opnieuw proberen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Verbind</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinden…</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Log in op uw XMPP-account</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Ongeldige gebruikersnaam of wachtwoord.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Kan geen verbinding maken met de server. Controleer uw internetverbinding.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">De server ondersteunt geen beveiligde verbindingen.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Fout bij het maken van een beveiligde verbinding.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Kan het adres van de server niet oplossen. Controleer uw JID opnieuw.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Kan geen verbinding maken met de server.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Authenticatieprotocol niet ondersteund door de server.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Er is een onbekende fout opgetreden; zie logboek voor details.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Log in met behulp van een QR-code</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Neem foto&apos;s</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Video opnemen</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Video opnemen</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Stuur locatie</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Kies bestand</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Kies een afbeelding</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Kies video</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Kies audiobestand</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Kies een document</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Geluid</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished">Document</translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">Afbeelding</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished">Bestand</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished">Spoiler</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Kan geen bericht verzenden, omdat er geen verbinding is gemaakt.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Bericht kon niet verbeterd worden, omdat er geen verbinding is.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Spoiler</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Het bericht kon niet worden verzonden.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Het corrigeren van het bericht is mislukt.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fout</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">Afbeelding</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Geluid</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Image</source>
        <translation type="obsolete">Afbeelding</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Geluid</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="obsolete">Video</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished">Beschikbaar</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished">Beschikbaar voor gesprek</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished">Afwezig</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished">Niet storen</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished">Langere tijd afwezig</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">Offline</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="vanished">Beschikbaar</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Beschikbaar voor gesprek</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Afwezig</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Niet storen</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Langere tijd afwezig</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Offline</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fout</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Niet zichtbaar</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished">Ongeldige gebruikersnaam of wachtwoord.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="unfinished">Kan geen verbinding maken met de server. Controleer uw internetverbinding.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="unfinished">De server ondersteunt geen beveiligde verbindingen.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="unfinished">Fout bij het maken van een beveiligde verbinding.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Kan geen verbinding maken met de server.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="unfinished">Authenticatieprotocol niet ondersteund door de server.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished">Scan een QR-code</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished">Het cameraformaat &apos;%1&apos; wordt niet ondersteund.</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished">Er is geen camera beschikbaar.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished">Uw camera is bezig.
Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">Scan een QR-code</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="vanished">Er is geen camera beschikbaar.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="vanished">Uw camera is bezig.
Probeer andere applicaties die de camera gebruiken te sluiten.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="vanished">Het cameraformaat &apos;%1&apos; wordt niet ondersteund.</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Uw wachtwoord is veranderd.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Fout bij het wijzigen van wachtwoord: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Verwijder</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Voeg nieuw contact toe</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Bijnaam:</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Jabber-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>gebruiker@voorbeeld.nl</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Voeg toe</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Dit stuurt ook een verzoek om aanwezigheidsupdates naar het contact.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Optioneel bericht:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Vertel je gesprekspartner wie je bent.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Offline</source>
        <translation type="obsolete">Offline</translation>
    </message>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Fout: Controleer nogmaals het JID.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Beschikbaar</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Beschikbaar voor gesprek</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Afwezig</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Niet storen</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Langere tijd afwezig</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fout</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Kan geen contact toevoegen omdat er geen verbinding is.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Kan het contact niet verwijderen omdat er geen verbinding is.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Spoiler</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>De naam van het contact kon niet worden veranderd, doordat er geen verbinding beschikbaar is.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Contacten</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Voeg nieuw contact toe</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinding maken…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Door contacten zoeken</translation>
    </message>
    <message>
        <source>Search…</source>
        <translation type="vanished">Zoeken…</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &quot;%1&quot; from your roster?</source>
        <translation type="vanished">Wil je echt contact &quot;%1&quot; uit je contactenlijst verwijderen?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Verwijder contact</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Wil je echt het contact &lt;b&gt;%1&lt;/b&gt; uit je contactenlijst verwijderen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Naam van contact veranderen</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Naam wijzigen:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Verstuur</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Bijschrift</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Instellingen</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished">Deze instelling verandert het wachtwoord van uw account. Als u ingelogd bent op andere apparaten zult u het daar opnieuw in moeten voeren.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on a new device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Wachtwoord wijzigen</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Deze instelling verandert het wachtwoord van uw account. Als u ingelogd bent op andere apparaten zult u het daar opnieuw in moeten voeren.</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Abonneerverzoek</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Je hebt een abonneringsverzoek ontvangen van &lt;b&gt;%1&lt;/b&gt;. Als je toestemt heeft deze account toegang tot je aanwezigheidsupdates.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Afwijzen</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepteren</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Kon bestand niet verzenden omdat er geen verbinding is.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Bestand</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished">Het bericht kon niet worden verzonden.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Profiel</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished">Naam van contact veranderen</translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Bijnaam</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Verjaardag</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
</context>
</TS>
